@@ -195,12 +195,12 @@ test_that("tidy method - multi-class", {
     xrf_cls_mod %>%
     fit(class ~ ., data = hpc_data$hpc_mod)
 
-  xrf_rule_res <- tidy(xrf_cls_fit)
+  xrf_rule_res <- tidy(xrf_cls_fit, penalty = .001)
   expect_true(length(unique(xrf_rule_res$class)) == 4)
   expect_true(sum(xrf_rule_res$rule == "( TRUE )") == 4)
   expect_true(sum(xrf_rule_res$rule_id == "(Intercept)") == 4)
 
-  xrf_col_res <- tidy(xrf_cls_fit, unit = "column")
+  xrf_col_res <- tidy(xrf_cls_fit, unit = "column", penalty = .001)
   expect_true(length(unique(xrf_col_res$class)) == 4)
   expect_true(sum(xrf_col_res$term == "(Intercept)") == 4)
   expect_true(sum(xrf_col_res$rule_id == "(Intercept)") == 4)
